@@ -1,5 +1,5 @@
-#  tests for firefox-72.0.2-h6538335_0 (this is a generated file);
-print('===== testing package: firefox-72.0.2-h6538335_0 =====');
+#  tests for firefox-74.0-h6538335_0 (this is a generated file);
+print('===== testing package: firefox-74.0-h6538335_0 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 """ test whether firefox is viable with geckodriver and selenium
@@ -63,4 +63,4 @@ if __name__ == "__main__":
             sys.exit(1)
 #  --- run_test.py (end) ---
 
-print('===== firefox-72.0.2-h6538335_0 OK =====');
+print('===== firefox-74.0-h6538335_0 OK =====');
